/*                                          
  Small Game Library
  v 0.0
*/ 
#include <SDL.h>
#include <SDL_image.h>
#include <SDL_mixer.h>
#include <SDL_ttf.h>

/* GP2X button mapping */
enum MAP_KEY
{
	VK_UP         , // 0
	VK_UP_LEFT    , // 1
	VK_LEFT       , // 2
	VK_DOWN_LEFT  , // 3
	VK_DOWN       , // 4
	VK_DOWN_RIGHT , // 5
	VK_RIGHT      , // 6
	VK_UP_RIGHT   , // 7
	VK_START      , // 8
	VK_SELECT     , // 9
	VK_FL         , // 10
	VK_FR         , // 11
	VK_FA         , // 12
	VK_FB         , // 13
	VK_FX         , // 14
	VK_FY         , // 15
	VK_VOL_UP     , // 16
	VK_VOL_DOWN   , // 17
	VK_TAT          // 18
};
typedef struct SDL_Surface surface;
typedef struct Mix_Chunk sound;

extern int joy[20];

//functions


//main-screen
SDL_Surface *sgl_start() ; //start sgl initialize sdl and open the screen | return the screen surface
void sgl_terminate(); //stop sdl and terminate the program        
void screenswap();//simulate the page swapping and update the events

SDL_Surface *surface_create(int w, int h, int trasparency);//create an empty surface
SDL_Surface *surface_load( char *filename, int trasparency);//load an image like surface
void surface_destroy( SDL_Surface *surface);//erase surface
void paste( SDL_Surface *dst, int x, int y, SDL_Surface *src);//blit a surface in another or in a screen
void blt( SDL_Surface *dst, int x, int y, SDL_Surface *src, int xs, int ys, int w, int h);//blit a part of surface in another


// graphics
Uint32 rgb( int r, int g, int b);//return a color from rgb
void cls( SDL_Surface *dst, Uint32 color); //clear all screen (needed after screen swap)

void plot( SDL_Surface *surface, int x, int y, Uint32 col );//plot a pixel in surface
Uint32 point( SDL_Surface *surface, int x, int y);//return the color of pixel in surface 0 if out of surface
void hline( SDL_Surface * surface, int x1, int y1, int x2, Uint32 color);// draw a horizontal line
void vline( SDL_Surface * surface, int x1, int y1, int y2, Uint32 color);// draw a vertical line
void line( SDL_Surface * surface, int x1, int y1, int x2, int y2, Uint32 color);// draw a line
void box( SDL_Surface *surface, int x, int y, int w, int h, Uint32 color);//draw a box
void bar( SDL_Surface *dst, int x, int y, int w, int h, Uint32 color);//trace a filled rectangle
void circle( SDL_Surface *surface, int vx, int vy, int r, Uint32 color);//draw a circle
void fillcircle( SDL_Surface *surface, int vx, int vy, int r, Uint32 color);//draw ma fill circle
void ellipse( SDL_Surface *surface, int vx, int vy, int Xradius, int Yradius, Uint32 color);// draw an ellipse
void fillellipse( SDL_Surface *surface, int vx, int vy, int Xradius, int Yradius, Uint32 color);//draw a fill ellipse

//sounds & music
Mix_Chunk *sound_load( char *filename);//load a sound
void sound_play( Mix_Chunk *snd, int channel, int volume, int loop);//play a sound
void sound_destroy(Mix_Chunk *snd);//remove a sound loaded

void music_load( char *filename);//load a music
void music_play( int volume, int loop);//loop=0 stop 1=play 2=looping

//text
void setfont( char *fontPath);
surface *text( char *string, int size, Uint32 col);//make a text as surface
